SystemOrganization addCategory: #'AJP-Tests-Pharo'!

AJPDefaultDataStream subclass: #AJPPharoMockDataStream
	instanceVariableNames: 'stream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AJP-Tests-Pharo'!

!AJPPharoMockDataStream commentStamp: 'pmm 12/8/2008 20:08' prior: 0!
An AJPSqueakDataStream is a an implementation of an AJPDataStream that uses a Squeak read stream as its implementation.

Instance Variables
	stream:		<ReadStream>

stream
	- the underlying stream from which is read, in binary mode!

!AJPPharoMockDataStream class methodsFor: 'instance creation' stamp: 'pmm 12/9/2008 20:03'!
on: aStream
	^self new initializeOn: aStream! !

!AJPPharoMockDataStream methodsFor: 'initialize-release' stamp: 'pmm 12/8/2008 20:06'!
initializeOn: aStream
	stream := aStream! !

!AJPPharoMockDataStream methodsFor: 'reading' stamp: 'pmm 12/8/2008 20:06'!
readByte
	"returns the next byte
	
	Spec:
	A single byte."
	^stream next! !

!AJPPharoMockDataStream methodsFor: 'reading' stamp: 'pmm 10/31/2010 11:22'!
readChunk: anInteger into: aCollection startingAt: startIndex
	"reads a String of the given size into the given stream"
	| data |
	data := stream next: anInteger.
	aCollection replaceFrom: startIndex to: startIndex + anInteger - 1 with: data startingAt: 1.! !

!AJPPharoMockDataStream methodsFor: 'reading' stamp: 'pmm 10/30/2010 17:50'!
readStringWithSizeHighByte: aByte
	"reads a String with the high byte of the size already read
	otherwise the same as #readString"
	| result bytes size |
	size := (aByte << 8) bitOr: (self readByte).
	size = 16rFFFF ifTrue: [
		^String new ].
	
	"convert bytes to Characters, we don't want to switch to text mode because that would reset the buffers"
	result := ByteString new: size.
	self readChunk: size into: result startingAt: 1.
	
	"skip 0 byte"
	stream next = 0
		ifFalse: [ self protocolError: '0x00 byte string terminator expected' ].
	^result! !

!AJPPharoMockDataStream methodsFor: 'writing' stamp: 'pmm 12/8/2008 20:07'!
writeByte: aByte
	stream nextPut: aByte! !

!AJPPharoMockDataStream methodsFor: 'writing' stamp: 'pmm 12/8/2008 20:07'!
writeBytes: aByteArray
	stream nextPutAll: aByteArray! !

!AJPPharoMockDataStream methodsFor: 'writing' stamp: 'pmm 12/26/2010 13:17'!
writeChunk: aBuffer
	stream
		next: aBuffer size
		putAll: aBuffer array
		startingAt: aBuffer arrayOffset! !

!AJPPharoMockDataStream methodsFor: 'writing' stamp: 'pmm 11/7/2010 11:45'!
writeString: aString
	self writeInteger: aString size.
	stream isBinary
		ifTrue: [ stream next: aString size putAll: aString asByteArray startingAt: 1 ]
		ifFalse: [ stream next: aString size putAll: aString asString startingAt: 1 ].
	self writeByte: 0! !

AJPResponseWriterTest subclass: #AJPPharoResponseWriterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AJP-Tests-Pharo'!

!AJPPharoResponseWriterTest methodsFor: 'private' stamp: 'pmm 12/26/2010 12:11'!
mockDataStreamClass
	^ AJPPharoMockDataStream! !

AJPRequestReaderTest subclass: #AJPPharoRequestReaderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AJP-Tests-Pharo'!

!AJPPharoRequestReaderTest methodsFor: 'private' stamp: 'pmm 12/26/2010 12:09'!
mockDataStreamClass
	^ AJPPharoMockDataStream! !
